==> owncloud-8.1.0p2.tgz: owncloud/settings/l10n/mk.js <==
OC.L10N.register(
    "settings",
    {
    "Security & setup warnings" : "Предупредувања за сигурност и подесувања",
    "Sharing" : "Споделување",
    "Server-side encryption" : "Енкрипција на страна на серверот",
    "External Storage" : "Надворешно складиште",
    "Cron" : "Крон",
    "Email server" : "Сервер за е-пошта",
    "Log" : "Записник",
    "Tips & tricks" : "Совети и трикови",
    "Updates" : "Ажурирања",
    "Authentication error" : "Грешка во автентикација",
    "Your full name has been changed." : "Вашето целосно име е променето.",
    "Unable to change full name" : "Не можам да го променам целото име",
    "Couldn't remove app." : "Не можам да ја отстранам апликацијата.",
    "Language changed" : "Јазикот е сменет",
    "Invalid request" : "Неправилно барање",
    "Admins can't remove themself from the admin group" : "Администраторите неможе да се избришат себеси од админ групата",
    "Unable to add user to group %s" : "Неможе да додадам корисник во група %s",
    "Unable to remove user from group %s" : "Неможе да избришам корисник од група %s",
    "Couldn't update app." : "Не можам да ја надградам апликацијата.",
    "Wrong password" : "Погрешна лозинка",
    "No user supplied" : "Нема корисничко име",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Ве молам дадете лозинка за поврат на администраторот, или сите кориснички податоци ќе бидат изгубени",
    "Wrong admin recovery password. Please check the password and try again." : "Погрешна лозинка за поврат на администраторот. Ве молам проверете ја лозинката и пробајте повторно.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Позадината не подржува промена на лозинката, но корисничкиот клуч за енкрипција беше успешно ажуриран.",
    "Unable to change password" : "Вашата лозинка неможе да се смени",
    "Enabled" : "Овозможен",
    "Not enabled" : "Не е овозможено",
    "A problem occurred, please check your log files (Error: %s)" : "Се случи грешка, ве молам проверете ги вашите датотеки за логови (Грешка: %s)",
    "Migration Completed" : "Миграцијата заврши",
    "Group already exists." : "Групата веќе постои.",
    "Unable to add group." : "Не можам да додадам група.",
    "Unable to delete group." : "Не можам да избришам група.",
    "log-level out of allowed range" : "нивото на логирање е надвор од дозволениот опсег",
    "Saved" : "Снимено",
    "test email settings" : "провери ги нагодувањата за електронска пошта",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Се случи грешка при праќање на порака. Ве молам проверете ги вашите подесувања. (Error: %s)",
    "Email sent" : "Е-порака пратена",
    "Email saved" : "Електронската пошта е снимена",
    "Sending..." : "Испраќам...",
    "All" : "Сите",
    "Please wait...." : "Ве молам почекајте ...",
    "Error while disabling app" : "Грешка при исклучувањето на апликацијата",
    "Disable" : "Оневозможи",
    "Enable" : "Овозможи",
    "Error while enabling app" : "Грешка при вклучувањето на апликацијата",
    "Updating...." : "Надградувам ...",
    "Error while updating app" : "Грешка додека ја надградувам апликацијата",
    "Updated" : "Надграден",
    "Select a profile picture" : "Одбери фотографија за профилот",
    "Very weak password" : "Многу слаба лозинка",
    "Weak password" : "Слаба лозинка",
    "So-so password" : "Така така лозинка",
    "Good password" : "Добра лозинка",
    "Strong password" : "Јака лозинка",
    "Delete" : "Избриши",
    "Groups" : "Групи",
    "Error creating group" : "Грешка при креирање на група",
    "A valid group name must be provided" : "Мора да се обезбеди валидно име на група",
    "undo" : "врати",
    "never" : "никогаш",
    "add group" : "додади група",
    "A valid username must be provided" : "Мора да се обезбеди валидно корисничко име ",
    "Error creating user" : "Грешка при креирање на корисникот",
    "A valid password must be provided" : "Мора да се обезбеди валидна лозинка",
    "__language_name__" : "__language_name__",
    "SSL root certificates" : "SSL root сертификати",
    "Info, warnings, errors and fatal issues" : "Информации, предупредувања, грешки и фатални работи",
    "Warnings, errors and fatal issues" : "Предупредувања, грешки и фатални работи",
    "Errors and fatal issues" : "Грешки и фатални работи",
    "Fatal issues only" : "Само фатални работи",
    "None" : "Ништо",
    "Login" : "Најава",
    "Plain" : "Чиста",
    "NT LAN Manager" : "NT LAN Менаџер",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "Allow apps to use the Share API" : "Дозволете апликациите да го користат API-то за споделување",
    "Allow users to share via link" : "Допушти корисниците да споделуваат со линкови",
    "Enforce password protection" : "Наметни заштита на лозинка",
    "Allow public uploads" : "Дозволи јавен аплоуд",
    "Set default expiration date" : "Постави основен датум на истекување",
    "Expire after " : "Истекува по",
    "days" : "денови",
    "Enforce expiration date" : "Наметни датум на траење",
    "Allow resharing" : "Овозможи повторно споделување",
    "Restrict users to only share with users in their groups" : "Ограничи корисниците да споделуваат со корисници во своите групи",
    "Exclude groups from sharing" : "Исклучи групи од споделување",
    "Execute one task with each page loaded" : "Изврши по една задача со секоја вчитана страница",
    "This is used for sending out notifications." : "Ова се користи за испраќање на известувања.",
    "Send mode" : "Мод на испраќање",
    "Encryption" : "Енкрипција",
    "From address" : "Од адреса",
    "mail" : "Електронска пошта",
    "Authentication method" : "Метод на автентификација",
    "Authentication required" : "Потребна е автентификација",
    "Server address" : "Адреса на сервер",
    "Port" : "Порта",
    "Credentials" : "Акредитиви",
    "SMTP Username" : "SMTP корисничко име",
    "SMTP Password" : "SMTP лозинка",
    "Test email settings" : "Провери ги нагодувањаа за електронска пошта",
    "Send email" : "Испрати пошта",
    "Log level" : "Ниво на логирање",
    "More" : "Повеќе",
    "Less" : "Помалку",
    "Version" : "Верзија",
    "by" : "од",
    "Documentation:" : "Документација:",
    "User Documentation" : "Корисничка документација",
    "Admin Documentation" : "Админстраторска документација",
    "Enable only for specific groups" : "Овозможи само на специфицирани групи",
    "Cheers!" : "Поздрав!",
    "Forum" : "Форум",
    "Get the apps to sync your files" : "Преземете апликации за синхронизирање на вашите датотеки",
    "Show First Run Wizard again" : "Прикажи го повторно волшебникот при првото стартување",
    "You have used <strong>%s</strong> of the available <strong>%s</strong>" : "Имате искористено <strong>%s</strong> од достапните <strong>%s</strong>",
    "Password" : "Лозинка",
    "Unable to change your password" : "Вашата лозинка неможе да се смени",
    "Current password" : "Моментална лозинка",
    "New password" : "Нова лозинка",
    "Change password" : "Смени лозинка",
    "Email" : "Е-пошта",
    "Your email address" : "Вашата адреса за е-пошта",
    "Profile picture" : "Фотографија за профил",
    "Upload new" : "Префрли нова",
    "Select new from Files" : "Одбери нова од датотеките",
    "Remove image" : "Отстрани ја фотографијата",
    "Either png or jpg. Ideally square but you will be able to crop it." : "Мора де биде png или jpg. Идеално квадрат, но ќе бидете во можност да ја исечете.",
    "Your avatar is provided by your original account." : "Вашиот аватар е креиран со вашата оригинална сметка",
    "Cancel" : "Откажи",
    "Choose as profile image" : "Одбери фотографија за профилот",
    "Language" : "Јазик",
    "Help translate" : "Помогни во преводот",
    "Username" : "Корисничко име",
    "Create" : "Создај",
    "Admin Recovery Password" : "Обновување на Admin лозинката",
    "Add Group" : "Додади група",
    "Group" : "Група",
    "Everyone" : "Секој",
    "Admins" : "Администратори",
    "Default Quota" : "Предефинирана квота",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Ве молам внесете квота за просторот (нпр: \"512 MB\" или \"12 GB\")",
    "Unlimited" : "Неограничено",
    "Other" : "Останато",
    "Full Name" : "Цело име",
    "Quota" : "Квота",
    "Storage Location" : "Локација на сториџот",
    "Last Login" : "Последна најава",
    "change full name" : "промена на целото име",
    "set new password" : "постави нова лозинка",
    "Default" : "Предефиниран"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> owncloud-10.0.7.tgz: owncloud/settings/l10n/mk.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Погрешна лозинка",
    "No user supplied" : "Нема корисничко име",
    "Authentication error" : "Грешка во автентикација",
    "Wrong admin recovery password. Please check the password and try again." : "Погрешна лозинка за поврат на администраторот. Ве молам проверете ја лозинката и пробајте повторно.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Позадината не подржува промена на лозинката, но корисничкиот клуч за енкрипција беше успешно ажуриран.",
    "Unable to change password" : "Вашата лозинка неможе да се смени",
    "Couldn't send reset email. Please contact your administrator." : "Не можам да истпратам порака за ресетирање. Ве молам контактирајте го вашиот администратор.",
    "Federated Cloud Sharing" : "Федерирано клауд споделување",
    "A problem occurred, please check your log files (Error: %s)" : "Се случи грешка, ве молам проверете ги вашите датотеки за логови (Грешка: %s)",
    "Migration Completed" : "Миграцијата заврши",
    "Group already exists." : "Групата веќе постои.",
    "Unable to add group." : "Не можам да додадам група.",
    "Unable to delete group." : "Не можам да избришам група.",
    "log-level out of allowed range" : "нивото на логирање е надвор од дозволениот опсег",
    "Saved" : "Снимено",
    "test email settings" : "провери ги нагодувањата за електронска пошта",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Се случи грешка при праќање на порака. Ве молам проверете ги вашите подесувања. (Error: %s)",
    "Email sent" : "Е-порака пратена",
    "Invalid mail address" : "Неправилна електронска адреса/пошта",
    "A user with that name already exists." : "Корисник со ова име веќе постои.",
    "Unable to create user." : "Неможе да додадам корисник.",
    "Your %s account was created" : "Вашата %s сметка е креирана",
    "Unable to delete user." : "Неможам да избришам корисник",
    "Forbidden" : "Забрането",
    "Invalid user" : "Неправилен корисник",
    "Unable to change mail address" : "Не можам да ја променам електронската адреса/пошта",
    "Your full name has been changed." : "Вашето целосно име е променето.",
    "Unable to change full name" : "Не можам да го променам целото име",
    "__language_name__" : "__language_name__",
    "Language changed" : "Јазикот е сменет",
    "Invalid request" : "Неправилно барање",
    "Admins can't remove themself from the admin group" : "Администраторите неможе да се избришат себеси од админ групата",
    "Unknown user" : "Непознат корисник",
    "Couldn't remove app." : "Не можам да ја отстранам апликацијата.",
    "Official" : "Официјален",
    "Approved" : "Одобрен",
    "All" : "Сите",
    "Enabled" : "Овозможен",
    "Not enabled" : "Не е овозможено",
    "No apps found for your version" : "За вашата верзија не се пронајдени апликации",
    "Please wait...." : "Ве молам почекајте ...",
    "Error while disabling app" : "Грешка при исклучувањето на апликацијата",
    "Disable" : "Оневозможи",
    "Enable" : "Овозможи",
    "Error while enabling app" : "Грешка при вклучувањето на апликацијата",
    "Updating...." : "Надградувам ...",
    "Error while updating app" : "Грешка додека ја надградувам апликацијата",
    "Updated" : "Надграден",
    "Uninstalling ...." : "Деинсталирам ...",
    "Error while uninstalling app" : "Грешка при деинсталација на апликацијата",
    "Uninstall" : "Деинсталирај",
    "App update" : "Надградба на апликацијата",
    "Experimental" : "Експериментален",
    "Add trusted domain" : "Додади доверлив домејн",
    "Migration started …" : "Миграцијата е започнаа ...",
    "Valid until {date}" : "Валидно до {date}",
    "Delete" : "Избриши",
    "Sending..." : "Испраќам...",
    "An error occurred: {message}" : "Се случи грешка: {message}",
    "Select a profile picture" : "Одбери фотографија за профилот",
    "Very weak password" : "Многу слаба лозинка",
    "Weak password" : "Слаба лозинка",
    "So-so password" : "Така така лозинка",
    "Good password" : "Добра лозинка",
    "Strong password" : "Јака лозинка",
    "Groups" : "Групи",
    "Unable to delete {objName}" : "Не можам да избришам {objName}",
    "Error creating group: {message}" : "Грешка при креирање на група: {message}",
    "A valid group name must be provided" : "Мора да се обезбеди валидно име на група",
    "deleted {groupName}" : "избришано {groupName}",
    "undo" : "врати",
    "never" : "никогаш",
    "deleted {userName}" : "избришан {userName}",
    "add group" : "додади група",
    "enabled" : "овозможен",
    "disabled" : "оневозможен",
    "no group" : "нема група",
    "A valid username must be provided" : "Мора да се обезбеди валидно корисничко име ",
    "Error creating user: {message}" : "Грешка при креирање на корисник: {message}",
    "A valid password must be provided" : "Мора да се обезбеди валидна лозинка",
    "A valid email must be provided" : "Мора да се обезбеди валидна електронска пошта",
    "Cheers!" : "Поздрав!",
    "Forum" : "Форум",
    "Developer documentation" : "Документација за програмери",
    "Documentation:" : "Документација:",
    "Enable only for specific groups" : "Овозможи само на специфицирани групи",
    "Cron" : "Крон",
    "Open documentation" : "Отвори ја документацијата",
    "Execute one task with each page loaded" : "Изврши по една задача со секоја вчитана страница",
    "Server-side encryption" : "Енкрипција на страна на серверот",
    "Enable server-side encryption" : "Овозможи енкрипција на страна на серверот",
    "Enable encryption" : "Овозможи енкрипција",
    "Start migration" : "Започни ја миграцијата",
    "Sharing" : "Споделување",
    "Allow apps to use the Share API" : "Дозволете апликациите да го користат API-то за споделување",
    "Allow users to share via link" : "Допушти корисниците да споделуваат со линкови",
    "Allow public uploads" : "Дозволи јавен аплоуд",
    "Enforce password protection" : "Наметни заштита на лозинка",
    "Set default expiration date" : "Постави основен датум на истекување",
    "Expire after " : "Истекува по",
    "days" : "денови",
    "Enforce expiration date" : "Наметни датум на траење",
    "Allow resharing" : "Овозможи повторно споделување",
    "Allow sharing with groups" : "Овозможи споделување со групи",
    "Restrict users to only share with users in their groups" : "Ограничи корисниците да споделуваат со корисници во своите групи",
    "Exclude groups from sharing" : "Исклучи групи од споделување",
    "Info, warnings, errors and fatal issues" : "Информации, предупредувања, грешки и фатални работи",
    "Warnings, errors and fatal issues" : "Предупредувања, грешки и фатални работи",
    "Errors and fatal issues" : "Грешки и фатални работи",
    "Fatal issues only" : "Само фатални работи",
    "Log" : "Записник",
    "What to log" : "Што да логирам",
    "None" : "Ништо",
    "Login" : "Најава",
    "Plain" : "Чиста",
    "NT LAN Manager" : "NT LAN Менаџер",
    "Email server" : "Сервер за е-пошта",
    "This is used for sending out notifications." : "Ова се користи за испраќање на известувања.",
    "Send mode" : "Мод на испраќање",
    "Encryption" : "Енкрипција",
    "From address" : "Од адреса",
    "mail" : "Електронска пошта",
    "Authentication method" : "Метод на автентификација",
    "Authentication required" : "Потребна е автентификација",
    "Server address" : "Адреса на сервер",
    "Port" : "Порта",
    "Credentials" : "Акредитиви",
    "SMTP Username" : "SMTP корисничко име",
    "SMTP Password" : "SMTP лозинка",
    "Test email settings" : "Провери ги нагодувањаа за електронска пошта",
    "Send email" : "Испрати пошта",
    "Security & setup warnings" : "Предупредувања за сигурност и подесувања",
    "All checks passed." : "Сите проверки се поминати.",
    "Tips & tricks" : "Совети и трикови",
    "How to do backups" : "Како да правам резервни копии",
    "Advanced monitoring" : "Напредно мониторирање",
    "Performance tuning" : "Нагодување на перформансите",
    "Improving the config.php" : "Подобруваер на config.php",
    "Theming" : "Поставување на тема",
    "Hardening and security guidance" : "Заштита и насоки за безбедност",
    "Get the apps to sync your files" : "Преземете апликации за синхронизирање на вашите датотеки",
    "Show First Run Wizard again" : "Прикажи го повторно волшебникот при првото стартување",
    "Profile picture" : "Фотографија за профил",
    "Upload new" : "Префрли нова",
    "Remove image" : "Отстрани ја фотографијата",
    "Cancel" : "Откажи",
    "Email" : "Е-пошта",
    "Your email address" : "Вашата адреса за е-пошта",
    "Password" : "Лозинка",
    "Unable to change your password" : "Вашата лозинка неможе да се смени",
    "Current password" : "Моментална лозинка",
    "New password" : "Нова лозинка",
    "Change password" : "Смени лозинка",
    "Language" : "Јазик",
    "Help translate" : "Помогни во преводот",
    "Unlimited" : "Неограничено",
    "Name" : "Име",
    "Username" : "Корисничко име",
    "Version" : "Верзија",
    "Personal" : "Лично",
    "Admin" : "Админ",
    "Error" : "Грешка",
    "E-Mail" : "E-Mail",
    "Create" : "Создај",
    "Admin Recovery Password" : "Обновување на Admin лозинката",
    "Add Group" : "Додади група",
    "Group" : "Група",
    "Everyone" : "Секој",
    "Admins" : "Администратори",
    "Default Quota" : "Предефинирана квота",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Ве молам внесете квота за просторот (нпр: \"512 MB\" или \"12 GB\")",
    "Other" : "Останато",
    "Full Name" : "Цело име",
    "Quota" : "Квота",
    "Storage Location" : "Локација на сториџот",
    "Last Login" : "Последна најава",
    "change full name" : "промена на целото име",
    "set new password" : "постави нова лозинка",
    "Default" : "Предефиниран"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
